aboutsummaryrefslogtreecommitdiffstatshomepage
path: root/nix/flake.nix
diff options
context:
space:
mode:
Diffstat (limited to 'nix/flake.nix')
-rw-r--r--nix/flake.nix14
1 files changed, 11 insertions, 3 deletions
diff --git a/nix/flake.nix b/nix/flake.nix
index 7c7daa6..1a60566 100644
--- a/nix/flake.nix
+++ b/nix/flake.nix
@@ -19,6 +19,10 @@
url = "github:agavra/tuicr";
inputs.nixpkgs.follows = "nixpkgs";
};
+ aibox = {
+ url = "github:ruifm/aibox";
+ inputs.nixpkgs.follows = "nixpkgs";
+ };
};
outputs =
@@ -27,6 +31,7 @@
nixpkgs,
home-manager,
tuicr,
+ aibox,
...
}:
let
@@ -34,9 +39,12 @@
pkgs = import nixpkgs {
inherit system;
overlays = [
- # Expose `pkgs.tuicr` so common.nix can list it next to other
- # packages without threading inputs into every module.
- (final: prev: { tuicr = tuicr.packages.${system}.default; })
+ # Expose external flake packages so common.nix can list them next to
+ # nixpkgs packages without threading inputs into every module.
+ (final: prev: {
+ tuicr = tuicr.packages.${system}.default;
+ aibox = aibox.packages.${system}.default;
+ })
];
# Whitelist specific unfree packages (claude-code,
# github-copilot-cli) instead of globally setting allowUnfree,